export declare class IgxSelectionAPIService {
    protected selection: Map<string, any[]>;
    protected prevSelection: Map<string, any[]>;
    get_selection(componentID: string): any[];
    get_prev_selection(componentID: string): any[];
    set_prev_selection(componentID: string, currSelection: any[]): void;
    set_selection(componentID: string, currSelection: any[]): void;
    get_selection_length(componentID: string): number;
    /**
     * Add item to component selection using item's ID.
     * @param componentID ID of the component, which we add new item to.
     * @param itemID ID of the item to add to component selection.
     * @param compareFunc Custom function that search for already existing item with the provided ID.
     *     If not presented then item is compared by reference (using ===).
     * @param currSelection Used internally only by the selection (select_items method) to accumulate selection for multiple items.
     *
     * @returns selection after the new item is added
     */
    select_item(componentID: string, itemID: any, compareFunc?: (item) => boolean, currSelection?: any[]): any[];
    /**
     * Add items to component selection using their IDs.
     * @param componentID ID of the component, which we add new items to.
     * @param itemIDs Array of IDs of the items to add to component selection.
     * @param compareFunc Custom function that search for already existing items with the provided IDs.
     * If not presented then items are compared by reference (using ===).
     *
     * @returns selection after the new item is added
     */
    select_items(componentID: string, itemIDs: any[], compareFunc?: (item) => boolean): any[];
    append_items(componentID: string, itemIDs: any[]): any[];
    /**
     * Remove item from component selection using item's ID.
     * @param componentID ID of the component, which we remove items from.
     * @param itemID ID of the item to remove from component selection.
     * @param compareFunc Custom function that compares item to deselect with those presented in the current selection.
     * If not presented, then the item equal by reference to any item from the selection (using ===) is removed.
     * @param currSelection Used internally only by the selection (deselect_items method) to accumulate deselected items.
     *
     * @returns selection after the item is removed
     */
    deselect_item(componentID: string, itemID: any, compareFunc?: (item) => boolean, currSelection?: any[]): any[];
    /**
     * Remove items from component selection using their IDs.
     * @param componentID ID of the component, which we remove items from.
     * @param itemID ID of the items to remove from component selection.
     * @param compareFunc Custom function that compares items to deselect with those presented in the current selection.
     * If not presented, then all items equal by reference to any item from the selection (using ===) are removed.
     *
     * @returns selection after the item is removed
     */
    deselect_items(componentID: string, itemIDs: any[], compareFunc?: (item) => boolean): any[];
    subtract_items(componentID: string, itemIDs: any[]): any[];
    is_item_selected(componentID: string, currItemID: any, compareFunc?: (item) => boolean): boolean;
    get_all_ids(data: any, primaryKey?: any): any;
    are_all_selected(componentID: string, data: any): boolean;
    are_none_selected(componentID: string): boolean;
}
